﻿using System;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.ComponentModel;

namespace GridSample
{
    public class MyDataObject: INotifyPropertyChanged
    {
        #region Private members

        private int? _int;
        private string _string;
        private ObservableCollection<MyDataObject> _children;

        #endregion // Private members

        #region Public Properties

        public int? Int 
        { 
            get
            {
                return this._int;
            }
            set
            {
                if (value != this._int)
                {
                    this._int = value;
                    RaisePropertyChanged("Int");
                }
            }
        }

        public string String
        {
            get
            {
                return this._string;
            }
            set
            {
                if (value != this._string)
                {
                    this._string = value;
                    RaisePropertyChanged("String");
                }
            }
        }

        public ObservableCollection<MyDataObject> Children
        {
            get
            {
                return this._children;
            }
            set
            {
                if (value != this._children)
                {
                    this._children = value;
                    RaisePropertyChanged("Children");
                }
            }
        }

        #endregion // Public Properties                

        #region Constructors

        public MyDataObject(int index)
        {
            this.Int = index;
            this.String = "Item " + index;
            this.Children = new ObservableCollection<MyDataObject>();
        }

        public MyDataObject()
        {

        }
        
        #endregion // Constructors

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion // INotifyPropertyChanged Members
    }

    public class MyData : ObservableCollection<MyDataObject>
    {
        public MyData()
        {
            FillDataCollection(this,5);

            foreach (MyDataObject item in this)
            {
                FillDataCollection(item.Children, 5);
            }
        }

        public static void FillDataCollection(IList<MyDataObject> collection, int rowCount)
        {
            for (int i = 0; i < rowCount; i++)
            {
                collection.Add(new MyDataObject(i)
                {
                    String = "Item " + i                    
                });
            }
        }
    }
}
